Rdocumentation
powered by
Learn R Programming
phylodyn (version 0.9.0)
steep_cyc_traj: Steep cyclical trajectory
Description
Steep cyclical trajectory
Usage
steep_cyc_traj(t)
Arguments
t
numeric vector of times at which to evaluate the trajectory function.
Value
A vector containing the trajectory value corresponding to every element in
t
.
Examples
Run this code
steep_cyc_traj(
0
:
20
)
Run the code above in your browser using
DataLab